@@ -5,7 +5,8 @@ package GFX::Enhancer::ImageRepresentation;
 sub new {
 	my ($class) = @_;
 
-	my $self = { points => (), }; ### points are indexes in rect img
+	my $self = { points => (), }; ### points are byte indexes in rect img
+					### they have colour other than white
 
 	$class = ref($class) || $class;
 
@@ -36,4 +37,4 @@ sub scan_in_image {
 
 }
 
-
+1;
