@@ -14,27 +14,38 @@ sub new {
 
 ### public methods
 
+sub higher_colour_than_this {
+	my ($self, $rgba2) = @_;
+
+	if ($rgba2->{rgba} > $self->{rgba}) {
+		return 1;
+	} else {
+		return 0;
+	}
+}
+
 sub red {
 	my $self = shift;
 
-	return $self->{rgba} << 8;
+	return $self->{rgba} << 4;
 }
 
 sub green {
 	my $self = shift;
 
-	return $self->{rgba} << 16;
+	return $self->{rgba} << 8;
 }
 
 sub blue {
 	my $self = shift;
 
-	return $self->{rgba} << 24;
+	return $self->{rgba} << 16;
 }
 
 sub alpha {
 	my $self = shift;
 
-	return $self->{rgba} << 32;
+	return $self->{rgba} << 24;
 }
 
+1;
